API reference
=============

.. currentmodule:: rnnr

Event
-----

.. autoclass:: Event

Runner
------

.. autoclass:: Runner
   :members:

.. _Handlers:

Handlers
--------

.. currentmodule:: rnnr.handlers

.. autoclass:: EarlyStopper
   :members:

.. autoclass:: Checkpointer
   :members:

.. autoclass:: InvalidStateError

.. _Attachments:

Attachments
-----------

.. currentmodule:: rnnr.attachments

.. autoclass:: Attachment
   :members:
   :show-inheritance:

.. autoclass:: ProgressBar

.. autoclass:: LambdaReducer

.. autoclass:: MeanReducer
